==> cloudt-boot-starter-log-3.2.5.96.15-20231226.060608-1-sources.jar: com/elitescloud/boot/log/model/bo/OperationLogDTO.java <==
package com.elitescloud.boot.log.model.bo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Builder;
import lombok.Data;

import javax.validation.constraints.NotBlank;

/**
 * @author : chen.niu
 * @description :
 * @date : 2023-11-27 19:42
 */
@Data
@Builder
public class OperationLogDTO {
    @ApiModelProperty("应用标识 （非必填，默认：取值spring.application.name，微服务工程名")
    private String appName;

    @ApiModelProperty("操作页面编码（非必填，默认：取值http request head获取请求）")
    private String menuCode;

    @ApiModelProperty("唯一业务类型（必填），业务对象名称，开发指定，规范：业务对象的名称应直观地描述其作用或所代表的实体，业务对象对应实体的DO名称 如：SysPlatformUdcDO，SysPlatformMenusDO")
    private String businessType;

    @ApiModelProperty("唯一业务参数（必填），重要参数：产品或开发需求文档上标注，如：订单编号，员工编号。 用于操作日志查询）")
    private String businessParam;

    @ApiModelProperty("操作类型，必填：使用OperationTypeEnum枚举 必填（枚举：创建，编辑，删除，审批，导出，导入，查询，其他）")
    private String operationType;

    @ApiModelProperty("操作类型名称，默认：使用操作类型枚举名称，如果是其他类型，必填")
    private String operationTypeName;

    @ApiModelProperty("操作描述（必填），操作主数据记录")
    private String operationDescription;

    @ApiModelProperty("操作前数据存储（非必填）")
    private String operationBeforeData;

    @ApiModelProperty("操作后数据存储（非必填）")
    private String operationAfterData;

    @ApiModelProperty("操作时间（必填）默认：当前时间")
    private String operationTime;
    @ApiModelProperty("操作人账号（非必填）默认：当前登录操作人")
    private String operationUserName;
    @ApiModelProperty("操作人名称（非必填）默认：当前登录操作人")
    private String operationName;
    @ApiModelProperty("操作人ID（非必填）默认：当前登录操作人")
    private Long operationUserId;
    @ApiModelProperty("操作请求地址 （非必填）默认：通过HTTP REQUEST获取地址")
    private String requestUrl;
    @ApiModelProperty(value = "租户ID：默认：当前操作人租户")
    private Long tenantId;
    @ApiModelProperty(value = "请求方式（非必填）默认：通过HTTP REQUEST获取")
    private String requestMethod;
    @ApiModelProperty(value = "操作IP （非必填）默认：当前请求IP")
    private String operationIp;

    @ApiModelProperty("是否成功（必填） 默认：true")
    private Boolean success;
    @ApiModelProperty(value = "失败描述，成功非必填，失败必填 ")
    private String exceptionDesc;

    @ApiModelProperty(value = "链路ID-系统生成")
    private String traceIdSys;
    @ApiModelProperty(value = "链路ID-其他链路工具，默认sk")
    private String traceIdExt;
    @ApiModelProperty(value = "token")
    private String token;

    @ApiModelProperty(value = "扩展1")
    private String ext1;
    @ApiModelProperty(value = "扩展2")
    private String ext2;
    @ApiModelProperty(value = "扩展3")
    private String ext3;

    @ApiModelProperty(value = "数据来源")
    private String source;

    @ApiModelProperty(value = "耗时")
    private Long delayed;
}

==> cloudt-boot-starter-log-3.3.14-0415-20240409.081101-2-sources.jar: com/elitescloud/boot/log/model/bo/OperationLogDTO.java <==
package com.elitescloud.boot.log.model.bo;

import com.elitescloud.boot.context.ExecutorContextHolder;
import io.swagger.annotations.ApiModelProperty;
import lombok.Builder;
import lombok.Data;

import javax.validation.constraints.NotBlank;

/**
 * @author : chen.niu
 * @description :
 * @date : 2023-11-27 19:42
 */
@Data
@Builder
public class OperationLogDTO {
    @ApiModelProperty("应用标识 （非必填，默认：取值spring.application.name，微服务工程名")
    private String appName;

    @ApiModelProperty("操作页面编码（非必填，默认：取值http request head获取请求）")
    private String menuCode;

    @ApiModelProperty("唯一业务类型（必填），业务对象名称，开发指定，规范：业务对象的名称应直观地描述其作用或所代表的实体，业务对象对应实体的DO名称 如：SysPlatformUdcDO，SysPlatformMenusDO")
    private String businessType;

    @ApiModelProperty("唯一业务参数（必填），重要参数：产品或开发需求文档上标注，如：订单编号，员工编号。 用于操作日志查询）")
    private String businessParam;

    @ApiModelProperty("操作类型，必填：使用OperationTypeEnum枚举 必填（枚举：创建，编辑，删除，审批，导出，导入，查询，其他）")
    private String operationType;

    @ApiModelProperty("操作类型名称，默认：使用操作类型枚举名称，如果是其他类型，必填")
    private String operationTypeName;

    @ApiModelProperty("操作描述（必填），操作主数据记录")
    private String operationDescription;

    @ApiModelProperty("操作前数据存储（非必填）")
    private String operationBeforeData;

    @ApiModelProperty("操作后数据存储（非必填）")
    private String operationAfterData;

    @ApiModelProperty("操作时间（必填）默认：当前时间")
    private String operationTime;
    @ApiModelProperty("操作人账号（非必填）默认：当前登录操作人")
    private String operationUserName;
    @ApiModelProperty("操作人名称（非必填）默认：当前登录操作人")
    private String operationName;
    @ApiModelProperty("操作人ID（非必填）默认：当前登录操作人")
    private Long operationUserId;
    @ApiModelProperty("操作请求地址 （非必填）默认：通过HTTP REQUEST获取地址")
    private String requestUrl;
    @ApiModelProperty(value = "租户ID：默认：当前操作人租户")
    private Long tenantId;
    @ApiModelProperty(value = "请求方式（非必填）默认：通过HTTP REQUEST获取")
    private String requestMethod;
    @ApiModelProperty(value = "操作IP （非必填）默认：当前请求IP")
    private String operationIp;

    @ApiModelProperty("是否成功（必填） 默认：true")
    private Boolean success;
    @ApiModelProperty(value = "失败描述，成功非必填，失败必填 ")
    private String exceptionDesc;

    @ApiModelProperty(value = "链路ID-系统生成")
    private String traceIdSys;
    @ApiModelProperty(value = "链路ID-其他链路工具，默认sk")
    private String traceIdExt;
    @ApiModelProperty(value = "token")
    private String token;

    @ApiModelProperty(value = "扩展1")
    private String ext1;
    @ApiModelProperty(value = "扩展2")
    private String ext2;
    @ApiModelProperty(value = "扩展3")
    private String ext3;

    @ApiModelProperty(value = "数据来源")
    private String source;

    /**
     * 操作来源
     *
     * 取值：{@link ExecutorContextHolder.Source}
     */
    @ApiModelProperty(value = "操作来源")
    private String executorSource;

    @ApiModelProperty(value = "耗时")
    private Long delayed;
}
